@@ -19,16 +19,6 @@ getCorners <- function(x) {
          yb=grobY(x, 270), yt=grobY(x, 90))
   }
 
-# Draw summary CI
-summary_ci <- function(est, lower, upper, size = 1, gp = gpar(), xlim){
-  polygonGrob(
-    x = c(lower, est, upper, est),
-    y = unit(0.5 + c(0, 0.5 * size, 0, -0.5 * size), "npc"),
-    gp = gp,
-    name = "summary.ci",
-    vp = viewport(xscale = xlim))
-}
-
 # Cehck if same length
 same_len <- function(...){
   lst <- list(...)
