@@ -6,24 +6,24 @@
 #' @param xlab X-axis label.
 #' @param is_exp If values is exponential.
 #' @param x0 Position of vertical line for 0 or 1.
+#' @param ticks_digits Number of digits for the x-axis, default is 1.
 #' @param gp Graphical parameters for arrow.
 #' @param xlim Limits for the x axis as a vector length 2, i.e. c(low, high)
 #'
 #' @return A grob
 #'
 #' @keywords internal
-make_xaxis <- function(at, xlab = NULL, x0 = 1, is_exp = FALSE, gp = gpar(), xlim){
+make_xaxis <- function(at, xlab = NULL, x0 = 1, is_exp = FALSE, ticks_digits = 1, gp = gpar(), xlim){
 
   if(is_exp){
-    label_at <- log(round(exp(at), 1))
+    label_at <- log(round(exp(at), ticks_digits))
     x0 <- log(x0)
-    labels <- as.character(round(exp(at), 1))
+    labels <- format(round(exp(at), ticks_digits), nsmall = ticks_digits)
   }else {
-    label_at <- round(at, 1)
-    labels <- as.character(round(at, 1))
+    label_at <- round(at, ticks_digits)
+    labels <- format(round(at, ticks_digits), nsmall = ticks_digits)
   }
 
-
   maj <- linesGrob(x = unit(c(min(xlim), max(xlim)), "native"),
                    y = unit(c(0.99, 0.99), "npc"),
                    gp = gp,
@@ -40,7 +40,7 @@ make_xaxis <- function(at, xlab = NULL, x0 = 1, is_exp = FALSE, gp = gpar(), xli
                   x = unit(label_at, "native"),
                   y = maj_cord$yb - unit(1, "lines"),
                   gp = gp,
-                  check.overlap=TRUE,
+                  # check.overlap=TRUE,
                   name = "label")
 
   if(!is.null(xlab)){
