@@ -3,8 +3,8 @@
 test_that("Test themes default value", {
   tm <- forest_theme()
   expect_type(tm, "list")
-  expect_equal(names(tm), c('legend', 'ci', 'xaxis', 'footnote', 'refline',
-                            'vertline', 'summary', 'tab_theme'))
+  expect_equal(names(tm), c('legend', 'ci', 'xaxis', 'footnote', "title",
+                            'refline', 'vertline', 'summary', 'tab_theme'))
 
   expect_identical(tm$legend, list('fontsize' = 12, 'fontfamily' = "",
                                    'name' = "Group", 'position' = "right",
